==> ejc-probuilddiary-api-3.0.0-20220916.063707-4-sources.jar: com/ejianc/business/probuilddiary/project/vo/ProjectLogSafetyVO.java <==
package com.ejianc.business.probuilddiary.project.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 项目日志-安全活动情况（安全员）
 *
 * @author baipengyan
 */
public class ProjectLogSafetyVO extends BaseVO {
	private static final long serialVersionUID = 5596373032929540578L;

	private Long personId; // 个人日志id
	private Long safetyId; // 工作类别id
	private String safetyName; // 工作类别名称
	private String safetyCode; // 工作类别编码
	private String safetyMemo; // 工作描述
	private Long commitUserId; // 提交人id
	private String commitUserCode; // 提交人账号
	private String commitUserName; // 提交人名称
	private Date commitDate; // 提交日期
	private Long projectLogId; // 项目日志id
	private String fileType; // 文件类型


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getSafetyId() {
		return safetyId;
	}

	public void setSafetyId(Long safetyId) {
		this.safetyId = safetyId;
	}

	public String getSafetyName() {
		return safetyName;
	}

	public void setSafetyName(String safetyName) {
		this.safetyName = safetyName;
	}

	public String getSafetyCode() {
		return safetyCode;
	}

	public void setSafetyCode(String safetyCode) {
		this.safetyCode = safetyCode;
	}

	public String getSafetyMemo() {
		return safetyMemo;
	}

	public void setSafetyMemo(String safetyMemo) {
		this.safetyMemo = safetyMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}
}

==> ejc-probuilddiary-api-3.0.0-20220919.091701-11-sources.jar: com/ejianc/business/probuilddiary/project/vo/ProjectLogSafetyVO.java <==
package com.ejianc.business.probuilddiary.project.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 项目日志-安全活动情况（安全员）
 *
 * @author baipengyan
 */
public class ProjectLogSafetyVO extends BaseVO {
	private static final long serialVersionUID = 5596373032929540578L;

	private Long personId; // 个人日志id
	private Long safetyId; // 工作类别id
	private String safetyName; // 工作类别名称
	private String safetyCode; // 工作类别编码
	private String safetyMemo; // 工作描述
	private Long commitUserId; // 提交人id
	private String commitUserCode; // 提交人账号
	private String commitUserName; // 提交人名称
	private Date commitDate; // 提交日期
	private Long projectLogId; // 项目日志id
	private String fileType; // 文件类型
	private Boolean updateFlag; // 更新状态


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getSafetyId() {
		return safetyId;
	}

	@ReferDeserialTransfer
	public void setSafetyId(Long safetyId) {
		this.safetyId = safetyId;
	}

	public String getSafetyName() {
		return safetyName;
	}

	public void setSafetyName(String safetyName) {
		this.safetyName = safetyName;
	}

	public String getSafetyCode() {
		return safetyCode;
	}

	public void setSafetyCode(String safetyCode) {
		this.safetyCode = safetyCode;
	}

	public String getSafetyMemo() {
		return safetyMemo;
	}

	public void setSafetyMemo(String safetyMemo) {
		this.safetyMemo = safetyMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}

	public Boolean getUpdateFlag() {
		return updateFlag;
	}

	public void setUpdateFlag(Boolean updateFlag) {
		this.updateFlag = updateFlag;
	}
}
